@@ -1,5 +1,6 @@
 import requests
 import json
+import copy
 
     
 ########
@@ -37,7 +38,7 @@ class ET_Constructor(object):
                 body = response[1]  #and the result in tuple position 1
 
                 # Store the Last Request ID for use with continue
-                if 'RequestID' in body:
+                if body and 'RequestID' in body:
                     self.request_id = body['RequestID']
 
                 if self.code == 200:
@@ -73,22 +74,25 @@ class ET_Constructor(object):
         return ws_object
 
     def parse_props_into_ws_object(self, auth_stub, obj_type, props):
+        empty_obj = auth_stub.soap_client.factory.create(obj_type)
         if props is not None and type(props) is dict:
-            ws_create = auth_stub.soap_client.factory.create(obj_type)
+            ws_create = copy.copy(empty_obj)
             ws_create = self.parse_props_dict_into_ws_object(obj_type, ws_create, props)
-            return ws_create            
+            return ws_create
         elif props is not None and type(props) is list:
             ws_create_list = []
             for prop_dict in props:
-                ws_create = auth_stub.soap_client.factory.create(obj_type)
+                #~ print str(datetime.now())+" - start"
+                ws_create = copy.copy(empty_obj)
                 ws_create = self.parse_props_dict_into_ws_object(obj_type, ws_create, prop_dict)
+                #~ print str(datetime.now())+" - start"
                 ws_create_list.append(ws_create)
             return ws_create_list
         else:
             message = 'Can not post properties to ' + obj_type + ' without a dict or list of properties'
             print message
-            raise Exception(message)        
-        
+            raise Exception(message)
+
 ########
 ##
 ##  Used to Describe Objects via web service call
@@ -109,6 +113,25 @@ class ET_Describe(ET_Constructor):
             self.message = 'Describe: ' + obj_type
             super(ET_Describe, self).__init__(response)
 
+########
+##
+##    Used to Configure Objects via web service call
+##
+########
+class ET_Configure(ET_Constructor):
+    def __init__(self, auth_stub, obj_type, props = None):        
+        auth_stub.refresh_token()
+
+        ws_configureRequest = auth_stub.soap_client.factory.create('ConfigureRequestMsg')
+        ws_configureRequest.Action = 'create'        
+        ws_configureRequest.Configurations = {'Configuration': self.parse_props_into_ws_object(auth_stub, obj_type, props)}
+
+        response = auth_stub.soap_client.service.Configure(None, ws_configureRequest)        
+
+        if response is not None:
+            #self.message = 'Describe: ' + obj_type
+            super(ET_Configure, self).__init__(response)
+
 ########
 ##
 ##  Get call to a web service
